"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeFile = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const filenamify_1 = __importDefault(require("filenamify"));
const log_1 = require("../log");
const writeFile = (list, output = './') => {
    const dir = path_1.default.resolve(output);
    const outputFile = [];
    log_1.info('输出路径', dir);
    fs_extra_1.default.ensureDirSync(dir);
    let writeStream = null;
    for (let item of list) {
        if (!item) {
            continue;
        }
        const { tags, title, categories, content, date } = item;
        const filename = path_1.default.join(dir, `./${filenamify_1.default(title)}.md`);
        try {
            writeStream = fs_extra_1.default.createWriteStream(filename, 'utf8');
            writeStream.write('---\n');
            writeStream.write(`title: ${title}\n`);
            writeStream.write(`date: ${date}\n`);
            writeStream.write(`tags: ${tags.join(' ')}\n`);
            writeStream.write(`categories: ${categories.join(' ')}\n`);
            writeStream.write('---\n\n');
            writeStream.write('<!--more-->\n\n');
            writeStream.write(content || '');
            writeStream.end('');
            writeStream.close();
            outputFile.push(filename);
        }
        catch (e) {
            log_1.error(`出错: ${title}`, e);
        }
        finally {
            if (writeStream) {
                writeStream.close();
            }
        }
    }
    return outputFile;
};
exports.writeFile = writeFile;
//# sourceMappingURL=writeFile.js.map